#[non_exhaustive]pub struct CreateExportInput {
pub export: Option<Export>,
pub resource_tags: Option<Vec<ResourceTag>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.export: Option<Export>The details of the export, including data query, name, description, and destination configuration.
An optional list of tags to associate with the specified export. Each tag consists of a key and a value, and each key must be unique for the resource.
Implementations
Sourceimpl CreateExportInput
impl CreateExportInput
Sourcepub fn export(&self) -> Option<&Export>
pub fn export(&self) -> Option<&Export>
The details of the export, including data query, name, description, and destination configuration.
An optional list of tags to associate with the specified export. Each tag consists of a key and a value, and each key must be unique for the resource.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .resource_tags.is_none().
Sourceimpl CreateExportInput
impl CreateExportInput
Sourcepub fn builder() -> CreateExportInputBuilder
pub fn builder() -> CreateExportInputBuilder
Creates a new builder-style object to manufacture CreateExportInput.